import {
	JupyterFrontEnd, JupyterFrontEndPlugin
} from '@jupyterlab/application';

import {
	NotebookPanel, INotebookTracker, Notebook
} from '@jupyterlab/notebook';

import {
	Cell, CodeCell
} from '@jupyterlab/cells';


import './codemirror-finesse';

const plugin: JupyterFrontEndPlugin<void> = {
	activate,
	id: 'finesse-syntax-jupyter',
	requires: [INotebookTracker],
	autoStart: true
};

function activate(app: JupyterFrontEnd, tracker: INotebookTracker) {
	tracker.widgetAdded.connect(activate_finesse)
};

function check_all(sender: Notebook): void {
	sender.widgets.forEach(cell => {
		if (cell instanceof CodeCell && cell.model.mimeType != "text/x-finesse-python") {
			cell.model.mimeType = "text/x-finesse-python";
		}
	});
};

function check_cell(sender: Notebook, cell: Cell): void {
	if (cell instanceof CodeCell) {
		cell.model.mimeType = "text/x-finesse-python";
	}
}

function activate_finesse(sender: INotebookTracker, panel: NotebookPanel): void {
	panel.content.activeCellChanged.connect(check_cell);

	// I ain't proud of this, but it's the sanest way I could find to get
	// the syntax highlighting to change on startup without selecting a
	// different cell
	setTimeout(() => {check_all(panel.content)}, 500);
};

export default plugin;
